;; Generated package description from graphql.el  -*- no-byte-compile: t -*-
(define-package "graphql" "0.1.1.0.20221029.130854" "GraphQL utilities" '((emacs "25")) :commit "4575642c3213593abe5972510c418ebb11bf1d99" :authors '(("Sean Allred" . "code@seanallred.com")) :maintainer '("Sean Allred" . "code@seanallred.com") :keywords '("hypermedia" "tools" "lisp") :url "https://github.com/vermiculus/graphql.el")
